import { Button, Col, Container, Form, Row } from "react-bootstrap";
import { Controller, useForm } from "react-hook-form";
import { useTranslation } from "react-i18next";
import validator from "validator";
import Divider from "../../components/layout/Divider";
import Modal from "../../components/Modal";

type FormData = {
  email: string;
  password: string;
};

function Login() {
    const {
      control,
      handleSubmit,
      formState: { errors },
    }= useForm<FormData>({
      mode: "onBlur"});
    const { t } = useTranslation();

    const onSubmit = (data: FormData) => {
      try {
        /**
         * Logic to handle authentication. Should be separated into a service in another file.
         * await login(data);
         *
         *
         * navigate("/boatManager");
         */
      } catch (e) {
        alert("error");
      }
    };

    return (
        <Container className="position-absolute top-50 start-50 translate-middle">
            <Row>
            <Col xs={{ span: 10, offset: 1 }}>
              <Modal>
                <h1 className="text-center p-1">{t("staffLogin.title")}</h1>
                <p className="text-center">{t("staffLogin.subtitle")}</p>
                <Divider />
                <Form onSubmit={handleSubmit(onSubmit)}>
                <Controller
                    name="email"
                    control={control}
                    defaultValue=""
                    render={({ field }) => (
                      <div className="mb-2">
                        <Form.Label>{t("staffLogin.labelEmail")}</Form.Label>
                        <Form.Control type="email" {...field} isInvalid={!!errors.email}/>
                        <Form.Control.Feedback type="invalid">
                          {errors.email?.message}
                        </Form.Control.Feedback>
                      </div>
                    )}
                    rules={{
                      required: {
                        value: true,
                        message: t("staffLogin.messages.required", {
                          val: t("staffLogin.labelEmail"),
                        }),
                      },
                      validate: (value: string) =>
                        validator.isEmail(value) ||
                        t("staffLogin.messages.invalidEmail").toString(),
                    }}
                  />
                  <Controller
                    name="password"
                    control={control}
                    defaultValue=""
                    render={({ field }) => (
                      <div className="mb-2">
                        <Form.Label>{t("staffLogin.labelPassword")}</Form.Label>
                        <Form.Control type="password" {...field} isInvalid={!!errors.password}/>
                        <Form.Control.Feedback type="invalid">
                          {errors.password?.message}
                        </Form.Control.Feedback>
                      </div>
                    )}
                    rules={{
                      required: {
                        value: true,
                        message: t("staffLogin.messages.required", {
                          val: t("staffLogin.labelPassword"),
                        }),
                      }
                    }}
                  />
                  <Button type="submit" variant="secondary" className="mt-2 w-100">
                    {t("staffLogin.buttonSignIn")}
                  </Button>
                </Form>
              </Modal>
            </Col>
            </Row>
        </Container>
    );

}

export default Login;
